@@ -21,19 +21,32 @@ def tax_placement(pident, tax_cutoffs):
 
     if pident >= tax_cutoffs['species']:
         out = 'species'
-        level = 7
+        level = 8
     elif pident >= tax_cutoffs['genus']:
         out = 'genus'
-        level = 6
+        level = 7
     elif pident >= tax_cutoffs['family']:
         out = 'family'
-        level = 5
+        level = 6
     elif pident >= tax_cutoffs['order']:
         out = 'order'
-        level = 4
-    elif pident < tax_cutoffs['order']:
+        level = 5
+    elif pident >= tax_cutoffs['class']:
         out = 'class'
+        level = 4
+    elif pident >= tax_cutoffs['division']:
+        out = 'division'
         level = 3
+    elif pident >= tax_cutoffs['supergroup']:
+        out = 'supergroup'
+        level = 2
+    elif pident >= tax_cutoffs['domain']:
+        out = 'domain'
+        level = 1
+    else:
+        out = 'unclassified'
+        level = 0
+        
     return out, level
 
 def read_in_taxonomy(infile):
@@ -42,16 +55,18 @@ def read_in_taxonomy(infile):
     with open(infile, 'rb') as f:
         result = chardet.detect(f.read())
     tax_out = pd.read_csv(infile, sep='\t',encoding=result['encoding'])
-    classes = ['supergroup','division','class','order',
+    classes = ['domain','supergroup','division','class','order',
                'family','genus','species']
+    classes_out = []
     for c in tax_out.columns:
         if c.lower() in classes:
             if (np.issubdtype(tax_out[str(c)].dtypes, np.number)) | \
                (np.issubdtype(tax_out[str(c)].dtypes, np.float_)):
                 tax_out = tax_out.loc[:,~(tax_out.columns == c)]
+            classes_out.append(c.lower())
     tax_out.columns = tax_out.columns.str.lower()
     tax_out = tax_out.set_index('source_id')
-    return tax_out
+    return tax_out, classes_out
 
 def read_in_tax_cutoffs(yamlfile):
     ''' Read taxonomic cutoff YAML file.'''
@@ -67,14 +82,13 @@ def read_in_protein_map(protjson):
         pout = ujson.load(f)
     return pout
 
-def gen_dict(tax_table):
+def gen_dict(tax_table,classes):
     ''' Create classication dictionary for easy lookup. '''
 
-    classes = ['supergroup','division','class','order',
-               'family','genus','species']
     tax_table["Classification"] = ""
     tax_table = tax_table.loc[:,~tax_table.columns.duplicated()]
     for c in classes:
+        tax_table.loc[tax_table[c] != tax_table[c], c] = "No " + c
         if all([str(curr).lower() != "nan" for curr in list(tax_table[c])]):
             if str(tax_table["Classification"][0]) != "":
                 tax_table["Classification"] = tax_table["Classification"] +\
@@ -89,10 +103,9 @@ def gen_reads_dict(names_to_reads):
     return dict(zip(names_to_reads["TranscriptNames"],
                     names_to_reads["NumReads"]))
 
-def lca(full_classifications):
+def lca(full_classifications,classes):
     ''' Last Common Ancestor (LCA) algorithm. '''
 
-    classes = ['supergroup','division','class','order','family','genus','species']
     full_classifications_split = [[str(subtax).strip() for
                                    subtax in curr.split(";")] for
                                   curr in full_classifications]
@@ -108,7 +121,7 @@ def lca(full_classifications):
                    "; ".join(full_classifications_split[0][0:(l+1)])
     return "","","" # if there are no common ancestors
 
-def match_maker(dd, consensus_cutoff, tax_dict, use_counts, tax_cutoffs):
+def match_maker(dd, consensus_cutoff, tax_dict, use_counts, tax_cutoffs, classes):
     ''' Manages decision between multiple matches. '''
 
     ambiguous = 0 # we assume unambiguous
@@ -169,7 +182,7 @@ def match_maker(dd, consensus_cutoff, tax_dict, use_counts, tax_cutoffs):
                 full_classification = best_full_class
             else:
                 assignment, best_classification, \
-                        full_classification = lca(full_classification_0)
+                        full_classification = lca(full_classification_0,classes)
 
     if use_counts == 1:
         return pd.DataFrame([[transcript_name, assignment,\
@@ -183,18 +196,19 @@ def match_maker(dd, consensus_cutoff, tax_dict, use_counts, tax_cutoffs):
                        columns=['transcript_name', 'classification_level', 'full_classification',
                                 'classification', 'max_pid', 'ambiguous'])
 
-def apply_parallel(grouped_data, match_maker, consensus_cutoff, tax_dict, use_counts, tax_cutoffs):
+def apply_parallel(grouped_data, match_maker, consensus_cutoff, tax_dict, use_counts, tax_cutoffs, classes):
     resultdf = Parallel(n_jobs=multiprocessing.cpu_count(),
                         prefer="threads")(delayed(match_maker)(group,
                                                                consensus_cutoff,
                                                                tax_dict,
                                                                use_counts,
-                                                               tax_cutoffs)
+                                                               tax_cutoffs,
+                                                               classes)
                                           for name, group in grouped_data)
     return pd.concat(resultdf)
 
 def classify_taxonomy_parallel(df, tax_dict, namestoreads, pdict,
-                               consensus_cutoff, tax_cutoffs):
+                               consensus_cutoff, tax_cutoffs, classes):
     ''' Parallel implementation of the taxonomic classication process. '''
 
     chunksize = 2 * 10 ** 6
@@ -215,6 +229,7 @@ def classify_taxonomy_parallel(df, tax_dict, namestoreads, pdict,
         chunk.columns = ['qseqid', 'sseqid', 'pident', 'length', 'mismatch',
                          'gapopen', 'qstart','qend', 'sstart', 'send',
                          'evalue', 'bitscore']
+        chunk.sseqid = [curr.replace(".","N") for curr in chunk.sseqid]
         chunk['ssqid_TAXID']=chunk.sseqid.map(pdict)
         chunk = chunk[['qseqid','pident', 'evalue', 'bitscore', 'ssqid_TAXID']]
         if namestoreads != 0:
@@ -229,11 +244,11 @@ def classify_taxonomy_parallel(df, tax_dict, namestoreads, pdict,
 
         if counter == 0:
             outdf = apply_parallel(chunk.groupby('qseqid'), match_maker,
-                                   consensus_cutoff, tax_dict, use_counts, tax_cutoffs)
+                                   consensus_cutoff, tax_dict, use_counts, tax_cutoffs, classes)
         else:
             outdf = pd.concat([outdf, apply_parallel(chunk.groupby('qseqid'),
                                                      match_maker, consensus_cutoff, tax_dict,
-                                                     use_counts, tax_cutoffs)], axis = 0)
+                                                     use_counts, tax_cutoffs, classes)], axis = 0)
         counter = counter + 1
     return outdf
 
@@ -245,18 +260,18 @@ def place_taxonomy(tax_file,cutoff_file,consensus_cutoff,prot_map_file,
         print("Taxonomic placement already complete at", outfile + "; will not re-run step.")
         return pd.read_csv(outfile, sep = "\t")
  
-    tax_table = read_in_taxonomy(tax_file)
+    tax_table, classes = read_in_taxonomy(tax_file)
     tax_cutoffs = read_in_tax_cutoffs(os.path.join(os.path.dirname(\
         os.path.realpath(__file__)), "static", cutoff_file))
     pdict = read_in_protein_map(prot_map_file)
-    tax_dict = gen_dict(tax_table)
+    tax_dict = gen_dict(tax_table,classes)
     consensus_cutoff = float(consensus_cutoff)
     if int(use_counts) == 1:
         reads_dict = gen_reads_dict(names_to_reads)
         classification_df = classify_taxonomy_parallel(diamond_file, tax_dict, reads_dict,
-                                                       pdict, consensus_cutoff, tax_cutoffs)
+                                                       pdict, consensus_cutoff, tax_cutoffs, classes)
     else:
         classification_df = classify_taxonomy_parallel(diamond_file, tax_dict, 0, pdict,
-                                                       consensus_cutoff, tax_cutoffs)
+                                                       consensus_cutoff, tax_cutoffs, classes)
     classification_df.to_csv(outfile, sep='\t')
     return outfile
